@@ -1,5 +1,5 @@
 #
-# $Id: Global.pm,v 4593d0076cfb 2015/02/11 06:50:55 gomor $
+# $Id: Global.pm,v fb8748327b72 2015/03/08 11:16:55 gomor $
 #
 # core::global Brik
 #
@@ -7,13 +7,13 @@ package Metabrik::Core::Global;
 use strict;
 use warnings;
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 4593d0076cfb $',
+      revision => '$Revision: fb8748327b72 $',
       tags => [ qw(core main global) ],
       attributes => { 
          device => [ qw(device) ],
@@ -38,6 +38,7 @@ sub brik_properties {
          auto_use_on_require => [ qw(0|1) ],
          auto_install_on_require => [ qw(0|1) ],
          exit_on_sigint => [ qw(0|1) ],
+         pid => [ qw(metabrik_main_pid) ],
       },
       attributes_default => {
          device => 'eth0',
@@ -55,6 +56,7 @@ sub brik_properties {
          auto_use_on_require => 1,
          auto_install_on_require => 0,
          exit_on_sigint => 0,
+         pid => $$,
       },
       commands => {
          sleep => [ ],
