@@ -1,5 +1,5 @@
 #
-# $Id: Shell.pm,v 3a248b5c55a2 2015/02/15 17:11:25 gomor $
+# $Id: Shell.pm,v fb8748327b72 2015/03/08 11:16:55 gomor $
 #
 # core::shell Brik
 #
@@ -7,13 +7,13 @@ package Metabrik::Core::Shell;
 use strict;
 use warnings;
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 use base qw(Term::Shell Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 3a248b5c55a2 $',
+      revision => '$Revision: fb8748327b72 $',
       tags => [ qw(core main shell) ],
       attributes => {
          echo => [ qw(0|1) ],
@@ -91,7 +91,9 @@ sub brik_init {
    # Note: Gnu readline() is blocking SIGs, we have to hit enter so 
    #       Ctrl+C is executed.
    $SIG{INT} = sub {
-      $self->debug && $self->log->debug("brik_init: INT captured");
+      $self->debug && $self->log->debug("SIGINT: captured for pid[$$] ".
+         ($$ == $self->global->pid ? '(main process)' : '')
+      );
       $self->_update_prompt;
       if ($self->global->exit_on_sigint) {
          $self->run_exit;
