@@ -1,5 +1,5 @@
 #
-# $Id: Command.pm,v 24b4b8bc245c 2015/02/26 06:03:56 gomor $
+# $Id: Command.pm,v fb8748327b72 2015/03/08 11:16:55 gomor $
 #
 # shell::command Brik
 #
@@ -7,13 +7,13 @@ package Metabrik::Shell::Command;
 use strict;
 use warnings;
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 24b4b8bc245c $',
+      revision => '$Revision: fb8748327b72 $',
       tags => [ qw(main shell command system) ],
       attributes => {
          as_array => [ qw(0|1) ],
@@ -47,7 +47,15 @@ sub system {
       return $self->log->error($self->brik_help_run('system'));
    }
 
-   my $command = join(' ', $cmd, @args);
+   # Remove undefined values from arguments
+   my @new;
+   for (@args) {
+      if (defined($_)) {
+         push @new, $_;
+      }
+   }
+
+   my $command = join(' ', $cmd, @new);
    my @toks = split(/\s+/, $command);
    my $bin = $toks[0];
 
@@ -80,7 +88,15 @@ sub capture {
       return $self->log->error($self->brik_help_run('capture'));
    }
 
-   my $command = join(' ', $cmd, @args);
+   # Remove undefined values from arguments
+   my @new;
+   for (@args) {
+      if (defined($_)) {
+         push @new, $_;
+      }
+   }
+
+   my $command = join(' ', $cmd, @new);
    my @toks = split(/\s+/, $command);
    my $bin = $toks[0];
 
