@@ -1,5 +1,5 @@
 #
-# $Id: History.pm,v 4593d0076cfb 2015/02/11 06:50:55 gomor $
+# $Id: History.pm,v c4dfcb2b79fa 2015/03/08 11:21:41 gomor $
 #
 # shell::history Brik
 #
@@ -7,13 +7,13 @@ package Metabrik::Shell::History;
 use strict;
 use warnings;
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 4593d0076cfb $',
+      revision => '$Revision: c4dfcb2b79fa $',
       tags => [ qw(main shell history) ],
       attributes => {
          history_file => [ qw(file) ],
@@ -165,8 +165,6 @@ sub exec {
    my $self = shift;
    my ($numbers) = @_;
 
-   my $context = $self->context;
-
    if (! defined($numbers)) {
       return $self->log->error($self->brik_help_run('exec'));
    }
@@ -180,12 +178,9 @@ sub exec {
       $lines = $self->get_range($numbers);
    }
 
-   for (@$lines) {
-      if (/^exit$/) {
-         exit(0);
-      }
-      $context->run('core::shell', 'cmd', $_);
-   }
+   my $shell = $self->shell;
+
+   $shell->cmdloop($lines);
 
    return 1;
 }
