@@ -1,5 +1,5 @@
 #
-# $Id: Rc.pm,v dce61eaad109 2015/02/12 19:56:45 gomor $
+# $Id: Rc.pm,v c4dfcb2b79fa 2015/03/08 11:21:41 gomor $
 #
 # shell::rc Brik
 #
@@ -7,13 +7,13 @@ package Metabrik::Shell::Rc;
 use strict;
 use warnings;
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: dce61eaad109 $',
+      revision => '$Revision: c4dfcb2b79fa $',
       tags => [ qw(main shell rc) ],
       attributes => {
          file => [ qw(file) ],
@@ -78,7 +78,6 @@ sub exec {
       return $self->log->error("exec: must give an ARRAYREF as argument");
    }
 
-   my $context = $self->context;
    my $shell = $self->shell;
 
    $shell->cmdloop($lines);
@@ -107,6 +106,7 @@ my \$user = \$ENV{USER}
 
 my \$datadir = "\$home/metabrik"
 my \$repository = "\$datadir/repository/lib"
+my \$sudo = "sudo -E \$0 --no-splash"
 
 push \@INC, \$repository
 run core::context update_available
@@ -116,6 +116,8 @@ set core::global ctimeout 20
 set core::global rtimeout 20
 
 use shell::command
+use brik::search
+use perl::module
 
 alias update_available "run core::context update_available"
 alias reuse "run core::context reuse"
@@ -133,6 +135,7 @@ alias history "run shell::history show"
 alias ! "run shell::history exec"
 alias cat "run shell::command capture cat"
 alias pwd "run core::shell pwd"
+alias su "system \$sudo"
 
 use shell::history
 run shell::history load
